@@ -23,15 +23,17 @@
  * files for a list of changes.  These files are distributed with
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
-#include "gtkaccelgroup.h"
-#include "gtkaccelmap.h"
-#include "gdk/gdkkeysyms.h"
-#include "gtkmarshalers.h"
-#include "gtksignal.h"
 
+#include <config.h>
 #include <string.h>
 #include <stdlib.h>
 
+#include "gtkaccelgroup.h"
+#include "gtkaccelmap.h"
+#include "gtkmain.h"		/* For _gtk_boolean_handled_accumulator */
+#include "gdk/gdkkeysyms.h"
+#include "gtkmarshalers.h"
+
 
 /* --- prototypes --- */
 static void gtk_accel_group_class_init	(GtkAccelGroupClass	*class);
@@ -66,42 +68,20 @@ gtk_accel_group_get_type (void)
 	(GBaseInitFunc) NULL,
 	(GBaseFinalizeFunc) NULL,
 	(GClassInitFunc) gtk_accel_group_class_init,
-	NULL,   /* clas_finalize */
+	NULL,   /* class_finalize */
 	NULL,   /* class_data */
 	sizeof (GtkAccelGroup),
 	0,      /* n_preallocs */
 	(GInstanceInitFunc) gtk_accel_group_init,
       };
 
-      object_type = g_type_register_static (G_TYPE_OBJECT,
-					    "GtkAccelGroup",
+      object_type = g_type_register_static (G_TYPE_OBJECT, "GtkAccelGroup",
 					    &object_info, 0);
     }
 
   return object_type;
 }
 
-static gboolean
-accel_activate_accumulator (GSignalInvocationHint *ihint,
-			    GValue                *return_accu,
-			    const GValue          *handler_return,
-			    gpointer               data)
-{
-  gboolean continue_emission;
-  gboolean handler_val;
-
-  /* handler returns whether the accelerator was handled */
-  handler_val = g_value_get_boolean (handler_return);
-
-  /* record that as result for this emission */
-  g_value_set_boolean (return_accu, handler_val);
-
-  /* don't continue if accelerator was handled */
-  continue_emission = !handler_val;
-
-  return continue_emission;
-}
-
 static void
 gtk_accel_group_class_init (GtkAccelGroupClass *class)
 {
@@ -114,20 +94,28 @@ gtk_accel_group_class_init (GtkAccelGroupClass *class)
   object_class->finalize = gtk_accel_group_finalize;
 
   class->accel_changed = NULL;
-  signal_accel_activate = g_signal_new ("accel_activate",
-					G_OBJECT_CLASS_TYPE (class),
-					G_SIGNAL_DETAILED,
-					0,
-					accel_activate_accumulator, NULL,
-					_gtk_marshal_BOOLEAN__OBJECT_UINT_FLAGS,
-					G_TYPE_BOOLEAN, 3, G_TYPE_OBJECT, G_TYPE_UINT, GDK_TYPE_MODIFIER_TYPE);
-  signal_accel_changed = g_signal_new ("accel_changed",
-				       G_OBJECT_CLASS_TYPE (class),
-				       G_SIGNAL_RUN_FIRST | G_SIGNAL_DETAILED,
-				       G_STRUCT_OFFSET (GtkAccelGroupClass, accel_changed),
-				       NULL, NULL,
-				       _gtk_marshal_VOID__UINT_FLAGS_BOXED,
-				       G_TYPE_NONE, 3, G_TYPE_UINT, GDK_TYPE_MODIFIER_TYPE, G_TYPE_CLOSURE);
+  signal_accel_activate =
+    g_signal_new ("accel_activate",
+		  G_OBJECT_CLASS_TYPE (class),
+		  G_SIGNAL_DETAILED,
+		  0,
+		  _gtk_boolean_handled_accumulator, NULL,
+		  _gtk_marshal_BOOLEAN__OBJECT_UINT_FLAGS,
+		  G_TYPE_BOOLEAN, 3,
+		  G_TYPE_OBJECT,
+		  G_TYPE_UINT,
+		  GDK_TYPE_MODIFIER_TYPE);
+  signal_accel_changed =
+    g_signal_new ("accel_changed",
+		  G_OBJECT_CLASS_TYPE (class),
+		  G_SIGNAL_RUN_FIRST | G_SIGNAL_DETAILED,
+		  G_STRUCT_OFFSET (GtkAccelGroupClass, accel_changed),
+		  NULL, NULL,
+		  _gtk_marshal_VOID__UINT_FLAGS_BOXED,
+		  G_TYPE_NONE, 3,
+		  G_TYPE_UINT,
+		  GDK_TYPE_MODIFIER_TYPE,
+		  G_TYPE_CLOSURE);
 }
 
 static void
@@ -269,11 +257,9 @@ gtk_accel_groups_from_object (GObject *object)
  *
  */
 GtkAccelKey*
-gtk_accel_group_find (GtkAccelGroup  *accel_group,
-		      gboolean (*find_func) (GtkAccelKey *key,
-					     GClosure    *closure,
-					     gpointer     data),
-		      gpointer        data)
+gtk_accel_group_find (GtkAccelGroup        *accel_group,
+		      GtkAccelGroupFindFunc find_func,
+		      gpointer              data)
 {
   GtkAccelKey *key = NULL;
   guint i;
@@ -458,6 +444,8 @@ quick_accel_find (GtkAccelGroup  *accel_group,
   GtkAccelGroupEntry *entry;
   GtkAccelGroupEntry key;
 
+  *count_p = 0;
+
   if (!accel_group->n_accels)
     return NULL;
 
@@ -475,7 +463,7 @@ quick_accel_find (GtkAccelGroup  *accel_group,
 	entry[-1].key.accel_mods != accel_mods)
       break;
   /* count equal members */
-  for (*count_p = 0; entry + *count_p < accel_group->priv_accels + accel_group->n_accels; (*count_p)++)
+  for (; entry + *count_p < accel_group->priv_accels + accel_group->n_accels; (*count_p)++)
     if (entry[*count_p].key.accel_key != accel_key ||
 	entry[*count_p].key.accel_mods != accel_mods)
       break;
@@ -733,16 +721,17 @@ gtk_accel_group_from_accel_closure (GClosure *closure)
 }
 
 gboolean
-_gtk_accel_group_activate (GtkAccelGroup  *accel_group,
-			   GQuark	   accel_quark,
-			   GObject	  *acceleratable,
-			   guint	   accel_key,
-			   GdkModifierType accel_mods)
+gtk_accel_group_activate (GtkAccelGroup   *accel_group,
+                          GQuark	   accel_quark,
+                          GObject	  *acceleratable,
+                          guint	           accel_key,
+                          GdkModifierType  accel_mods)
 {
   gboolean was_handled;
 
   g_return_val_if_fail (GTK_IS_ACCEL_GROUP (accel_group), FALSE);
-
+  g_return_val_if_fail (G_IS_OBJECT (acceleratable), FALSE);
+  
   was_handled = FALSE;
   g_signal_emit (accel_group, signal_accel_activate, accel_quark,
 		 acceleratable, accel_key, accel_mods, &was_handled);
@@ -782,7 +771,7 @@ gtk_accel_groups_activate (GObject	  *object,
       g_free (accel_name);
       
       for (slist = gtk_accel_groups_from_object (object); slist; slist = slist->next)
-	if (_gtk_accel_group_activate (slist->data, accel_quark, object, accel_key, accel_mods))
+	if (gtk_accel_group_activate (slist->data, accel_quark, object, accel_key, accel_mods))
 	  return TRUE;
     }
   
